==> haskell-wai-middleware-static-0.9.2-57-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-middleware-static.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wai-middleware-static
version:              0.9.2
visibility:           public
id:                   wai-middleware-static-0.9.2-BoKNtp5BvRH8Xbq2FlxvSe
key:                  wai-middleware-static-0.9.2-BoKNtp5BvRH8Xbq2FlxvSe
license:              BSD-3-Clause
copyright:            (c) 2012-2014 Andrew Farmer
maintainer:           Andrew Farmer <afarmer@ittc.ku.edu>
author:               Andrew Farmer <afarmer@ittc.ku.edu>
stability:            experimental
homepage:             https://github.com/scotty-web/wai-middleware-static
synopsis:             WAI middleware that serves requests to static files.
description:
    WAI middleware that intercepts requests to static files and serves them
    if they exist.

    [WAI] <http://hackage.haskell.org/package/wai>

category:             Web
abi:                  fcbadf5d38735f24299099e77a59b3db
exposed:              True
exposed-modules:      Network.Wai.Middleware.Static
import-dirs:          /usr/lib/ghc-9.0.2/site-local/wai-middleware-static-0.9.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/wai-middleware-static-0.9.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-middleware-static
hs-libraries:         HSwai-middleware-static-0.9.2-BoKNtp5BvRH8Xbq2FlxvSe
depends:
    base-4.15.1.0 base16-bytestring-1.0.2.0-1csYxhEsYs5IL7o3RWgSzs
    bytestring-0.10.12.1 containers-0.6.4.1
    cryptohash-sha1-0.11.101.0-JH70iwWQltzBU107CY3hoA directory-1.3.6.2
    expiring-cache-map-0.0.6.1-5juTIGiFhTYJNq976IUncm filepath-1.4.2.1
    http-types-0.12.3-6RljJIE0BOskjcX6KpVQv
    mime-types-0.1.0.9-7GDM5km4xFM2oMJfUcH43l
    old-locale-1.0.0.7-B94o3sNLYrV8oE3WO2rqHh text-1.2.5.0 time-1.9.3
    wai-3.2.3-JTeVW4dOWwH8LTc9CtqptJ

haddock-interfaces:
    /usr/share/doc/haskell-wai-middleware-static/html/wai-middleware-static.haddock

haddock-html:         /usr/share/doc/haskell-wai-middleware-static/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-middleware-static-0.9.2-59-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-middleware-static.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wai-middleware-static
version:              0.9.2
visibility:           public
id:                   wai-middleware-static-0.9.2-EiWDwUSP3LpF8qXHlbqgpd
key:                  wai-middleware-static-0.9.2-EiWDwUSP3LpF8qXHlbqgpd
license:              BSD-3-Clause
copyright:            (c) 2012-2014 Andrew Farmer
maintainer:           Andrew Farmer <afarmer@ittc.ku.edu>
author:               Andrew Farmer <afarmer@ittc.ku.edu>
stability:            experimental
homepage:             https://github.com/scotty-web/wai-middleware-static
synopsis:             WAI middleware that serves requests to static files.
description:
    WAI middleware that intercepts requests to static files and serves them
    if they exist.

    [WAI] <http://hackage.haskell.org/package/wai>

category:             Web
abi:                  febe81fe39841daa631b53c104ab9787
exposed:              True
exposed-modules:      Network.Wai.Middleware.Static
import-dirs:          /usr/lib/ghc-9.0.2/site-local/wai-middleware-static-0.9.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/wai-middleware-static-0.9.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-middleware-static
hs-libraries:         HSwai-middleware-static-0.9.2-EiWDwUSP3LpF8qXHlbqgpd
depends:
    base-4.15.1.0 base16-bytestring-1.0.2.0-9zSRL739pinDfbBVWkcRI2
    bytestring-0.10.12.1 containers-0.6.4.1
    cryptohash-sha1-0.11.101.0-6uEUc9oItIuJ5ctRmin4K1 directory-1.3.6.2
    expiring-cache-map-0.0.6.1-Dicm74MxXK7AHpNbadKbRf filepath-1.4.2.1
    http-types-0.12.3-6SjaEFyZrR71uf1AqCfbdK
    mime-types-0.1.0.9-7GDM5km4xFM2oMJfUcH43l
    old-locale-1.0.0.7-B94o3sNLYrV8oE3WO2rqHh text-1.2.5.0 time-1.9.3
    wai-3.2.3-Ec5IYfflqSc74IJaeojcpJ

haddock-interfaces:
    /usr/share/doc/haskell-wai-middleware-static/html/wai-middleware-static.haddock

haddock-html:         /usr/share/doc/haskell-wai-middleware-static/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
